@@ -36,7 +36,7 @@ use vars qw/ $VERSION $DEBUG @ISA /;
 use Exporter 'import';
 our @EXPORT_OK = qw( translate_from_FITS translate_to_FITS );
 
-$VERSION = '1.61';
+$VERSION = '1.62';
 $DEBUG   = 0;
 
 # The reference list of classes we can try This list should be
@@ -46,7 +46,7 @@ $DEBUG   = 0;
 # here. This is because some perl modules provide a base set of
 # translations shared by multiple instruments.
 
-my @REF_CLASS_LIST = qw/ ACSIS IRCAM CGS4New CGS4Old UIST UFTI
+my @REF_CLASS_LIST = qw/ ACSIS IRCAM CGS4New CGS4Old UIST UFTI RxH3
                          JCMT_GSD JCMT_GSD_DB MICHELLE SCUBA SCUBA2 UKIRTDB WFCAM IRIS2 SOFI
                          ISAAC NACO INGRID GMOS SPEX NIRI ClassicCam CURVE LCOSBIG_CC
                          LCOSBIG_1m0 LCOSBIG_0m4 LCOSBIG_0m8 LCOSINISTRO_1m0
@@ -134,6 +134,7 @@ my @generic_headers = qw(
                           NUMBER_OF_CYCLES
                           NUMBER_OF_DETECTORS
                           NUMBER_OF_EXPOSURES
+                          NUMBER_OF_FREQUENCIES
                           NUMBER_OF_JITTER_POSITIONS
                           NUMBER_OF_MICROSTEP_POSITIONS
                           NUMBER_OF_OFFSETS
@@ -155,6 +156,7 @@ my @generic_headers = qw(
                           RA_TELESCOPE_OFFSET
                           RECEIVER_TEMPERATURE
                           REFERENCE_LOCATION
+                          REMOTE
                           REST_FREQUENCY
                           ROTATION
                           SAMPLE_MODE
@@ -162,6 +164,7 @@ my @generic_headers = qw(
                           SCAN_INCREMENT
                           SCAN_PATTERN
                           SEEING
+                          SHIFT_TYPE
                           SLIT_ANGLE
                           SLIT_NAME
                           SLIT_WIDTH
@@ -173,6 +176,7 @@ my @generic_headers = qw(
                           SWITCH_MODE
                           SYSTEM_TEMPERATURE
                           SYSTEM_VELOCITY
+                          TAI_UTC_CORRECTION
                           TAU
                           TELESCOPE
                           TILE_NUMBER
@@ -182,6 +186,7 @@ my @generic_headers = qw(
                           UTDATE
                           UTEND
                           UTSTART
+                          UT1_UTC_CORRECTION
                           VELOCITY
                           VELOCITY_REFERENCE_FRAME
                           VELOCITY_TYPE
